@@ -438,6 +438,10 @@ class ClustersApi(object):
         >>> thread = api.clusters_get(async_req=True)
         >>> result = thread.get()
 
+        :param limit: The maximum number of elements to return. Use together with 'offset' for pagination.
+        :type limit: int
+        :param offset: The first element to return. Use together with 'limit' for pagination.
+        :type offset: int
         :param filter_name: Response filter to list only the PostgreSQL clusters that contain the specified name. The value is case insensitive and matched on the 'displayName' field. 
         :type filter_name: str
         :param async_req: Whether to execute the request asynchronously.
@@ -468,6 +472,10 @@ class ClustersApi(object):
         >>> thread = api.clusters_get_with_http_info(async_req=True)
         >>> result = thread.get()
 
+        :param limit: The maximum number of elements to return. Use together with 'offset' for pagination.
+        :type limit: int
+        :param offset: The first element to return. Use together with 'limit' for pagination.
+        :type offset: int
         :param filter_name: Response filter to list only the PostgreSQL clusters that contain the specified name. The value is case insensitive and matched on the 'displayName' field. 
         :type filter_name: str
         :param async_req: Whether to execute the request asynchronously.
@@ -496,6 +504,8 @@ class ClustersApi(object):
         local_var_params = locals()
 
         all_params = [
+            'limit',
+            'offset',
             'filter_name'
         ]
         all_params.extend(
@@ -519,11 +529,19 @@ class ClustersApi(object):
             local_var_params[local_var_params_key] = local_var_params_val
         del local_var_params['kwargs']
 
+        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
+            raise ApiValueError("Invalid value for parameter `limit` when calling `clusters_get`, must be a value less than or equal to `1000`")  # noqa: E501
+        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
+            raise ApiValueError("Invalid value for parameter `limit` when calling `clusters_get`, must be a value greater than or equal to `1`")  # noqa: E501
         collection_formats = {}
 
         path_params = {}
 
         query_params = list(local_var_params.get('query_params', {}).items())
+        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
+            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
+        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
+            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
         if 'filter_name' in local_var_params and local_var_params['filter_name'] is not None:  # noqa: E501
             query_params.append(('filter.name', local_var_params['filter_name']))  # noqa: E501
 
